from fediverse_service import FediverseService
from misskey_service import MisskeyService
from pleroma_service import PleromaService


class FediverseServiceFactory:
    """Factory for creating FediverseService implementations"""
    
    @staticmethod
    def create_service(instance_type: str) -> FediverseService:
        """
        Create a FediverseService implementation based on the instance type.
        
        Args:
            instance_type: The type of instance ("misskey" or "pleroma")
        
        Returns:
            FediverseService implementation (MisskeyService or PleromaService)
            
        Raises:
            ValueError: If the instance type is not supported
        """
        instance_type = instance_type.lower()
        
        if instance_type == "misskey":
            return MisskeyService()
        elif instance_type == "pleroma":
            return PleromaService()
        else:
            raise ValueError(f"Unsupported instance type: {instance_type}")


def get_fediverse_service(instance_type: str) -> FediverseService:
    """
    Convenience function to get a FediverseService instance
    
    Args:
        instance_type: The instance type ("misskey" or "pleroma")
    """
    return FediverseServiceFactory.create_service(instance_type)